import React from 'react';

import { FieldArray, ErrorMessage } from 'formik';

import InputProps from 'models/InputProps';
import InputOption from 'models/InputOption';

import RequiredField from './forms/RequiredField';

interface State {
  position: string;
  grid?: string;
  containerClass?: string;
  groupClass?: string;
  isRequired?: boolean;
}

class CheckboxGroup extends React.PureComponent<InputProps, State> {
  constructor(props: any) {
    super(props);
    this.state = {
      position: 'inline',
    };
  }

  componentDidMount() {
    this.setPosition();
  }

  setPosition() {
    if (this.props.field.position) {
      this.setState({
        position: this.props.field.position,
      });

      if (this.props.field.position === 'grid') {
        this.setState({
          grid: `col-md-${this.props.field.positionGrid}`,
          containerClass: 'row',
        });
      }
    }
  }

  render() {
    return (
      <div className={this.props.classes}>
        <label htmlFor={this.props.name} className={this.props.lClass}>
          {this.props.field.label}{' '}
          {this.props.field.isRequired && <RequiredField />}
        </label>
        <FieldArray
          name={this.props.name}
          render={arrayHelpers => (
            <div className={`${this.props.dClass}`}>
              <div className={`${this.state.containerClass}`}>
                {this.props.field.options!.map((o: InputOption) => (
                  <div
                    key={o.id}
                    className={`cb cb-primary ${this.state.grid} ${this.state.position}`}
                  >
                    <input
                      name={this.props.name}
                      type="checkbox"
                      id={o.id}
                      value={o.id}
                      checked={this.props.form.values[this.props.name].includes(
                        o.id
                      )}
                      disabled={o.disabled}
                      onChange={e => {
                        if (e.target.checked) {
                          arrayHelpers.push(o.id);
                        } else {
                          const idx = this.props.form.values[
                            this.props.name
                          ].indexOf(o.id);
                          arrayHelpers.remove(idx);
                        }
                      }}
                    />
                    <label htmlFor={o.id}>{o.label}</label>
                  </div>
                ))}
              </div>
              <ErrorMessage
                name={this.props.name}
                component="div"
                className="required"
              />
            </div>
          )}
        />
      </div>
    );
  }
}

export default CheckboxGroup;
